@@ -13,7 +13,7 @@ import PIL.Image
 class NpEncoder(json.JSONEncoder):
     def default(self, obj):
         if isinstance(obj, np.integer):
-            return int(obj)
+            return float(obj)
         if isinstance(obj, np.floating):
             return float(obj)
         if isinstance(obj, np.ndarray):
@@ -52,7 +52,7 @@ class LabelmeToCoco():
         self.info["description"] = self.project_desc
         date = datetime.now()
         self.info["version"] = "1.0"
-        self.info["year"] = date.year
+        # self.info["year"] = date.year
         self.info["date_created"] = str(date)
 
     def data_transfer(self):
@@ -108,7 +108,7 @@ class LabelmeToCoco():
         y = contour[:, 1]
         #area of bounding polgon
         area = 0.5 * np.abs(np.dot(x, np.roll(y, 1)) - np.dot(y, np.roll(x, 1)))
-        annotation["segmentation"] = [list(np.asarray(points).flatten())]
+        # annotation["segmentation"] = [[list(np.asarray(points).flatten())]]
         annotation["iscrowd"] = 0
         annotation["area"] = area
         annotation["image_id"] = num
